OSSP CVS Repository

ossp - Check-in [1278]
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [Patchset]  [Tagging/Branching

Check-in Number: 1278
Date: 2001-Nov-08 10:53:33 (local)
2001-Nov-08 09:53:33 (UTC)
User:rse
Branch:
Comment: switch to devtool stuff (taken over from OSSP SA)
Tickets:
Inspections:
Files:
ossp-pkg/l2/.configure      1.2->removed
ossp-pkg/l2/Makefile.in      1.31 -> 1.32     7 inserted, 36 deleted
ossp-pkg/l2/autogen.sh      1.4->removed
ossp-pkg/l2/devtool      added-> 1.1
ossp-pkg/l2/devtool.conf      added-> 1.1
ossp-pkg/l2/devtool.func      added-> 1.1
ossp-pkg/l2/l2_version.c      1.3 -> 1.4     10 inserted, 10 deleted

ossp-pkg/l2/.configure 1.2 -> 1.3



ossp-pkg/l2/Makefile.in 1.31 -> 1.32

--- Makefile.in  2001/11/07 16:18:38     1.31
+++ Makefile.in  2001/11/08 09:53:33     1.32
@@ -114,21 +114,11 @@
     l2_ut_sa.c \
     l2_version.c
 
-#   file containing the official version information
-_VERSION_FILE = \
-    l2_version.c
-
-#   helper macro for updating version information
-_VERSION = \
-    $(SHTOOL) version -lc -nL2 -pl2_ $$OPT $(_VERSION_FILE);\
-    V=`$(SHTOOL) version -lc -dlong $(_VERSION_FILE)`;\
-    sed -e "s/Version .*(.*)/Version $$V/g" <README >README.n && mv README.n README
-
 #   helper macro for generating a Unix manual page
 _MANPAGE = \
-    V1=`$(SHTOOL) version -lc -dshort $(_VERSION_FILE)`; \
-    V2=`$(SHTOOL) version -lc -dlong $(_VERSION_FILE)`; \
-    D=`$(SHTOOL) version -lc -dlong $(_VERSION_FILE) |\
+    V1=`$(SHTOOL) version -lc -dshort l2_version.c`; \
+    V2=`$(SHTOOL) version -lc -dlong l2_version.c`; \
+    D=`$(SHTOOL) version -lc -dlong l2_version.c |\
        sed -e 's;.*(;;' -e 's;).*;;'`; \
     $(POD2MAN) --section=$${SEC} --center="$${ONELINE}" \
                --release="$$D" --date="$${NAME} $$V1" $(S)$${BASENAME}.pod |\
@@ -181,15 +171,15 @@
         $(LIBTOOL) --mode=link --quiet $(CC) $(LDFLAGS) -o l2_sockmon l2_sockmon.o $(LIBS)
 
 #   build Unix manual pages
-l2-config.1: l2-config.pod $(_VERSION_FILE)
+l2-config.1: l2-config.pod l2_version.c
         BASENAME="l2-config"; SEC=1; \
         NAME="L2"; ONELINE="Logging Library"; \
         $(_MANPAGE)
-l2.3: l2.pod $(_VERSION_FILE)
+l2.3: l2.pod l2_version.c
         BASENAME="l2"; SEC=3; \
         NAME="L2"; ONELINE="Logging Library"; \
         $(_MANPAGE)
-l2++.3: l2++.pod $(_VERSION_FILE)
+l2++.3: l2++.pod l2_version.c
         BASENAME="l2++"; SEC=3; \
         NAME="L2"; ONELINE="Logging Library (C++)"; \
         $(_MANPAGE)
@@ -267,7 +257,7 @@
         $(RM) l2.h
 
 #   remove everything which can be regenerated
-#   by "autoconf && autoheader && ./configure && make all"
+#   by "./devtool autogen"
 realclean: distclean
         $(RM) configure
         $(RM) config.guess config.sub
@@ -280,25 +270,6 @@
         $(RM) l2_spec_scan.c
         $(RM) l2_spec_parse.c l2_spec_parse.h
 
-#   roll a distribution tarball
-dist: distclean
-        @$(SHTOOL) fixperm -v .; \
-        V=`$(SHTOOL) version -l c -d short l2_version.c`; \
-        $(SHTOOL) tarball -o l2-$${V}.tar.gz -d str-$${V} -u ossp -g ossp \
-                          -e 'CVS,\.cvsignore,\.[ao],^\.,autogen.sh' -c 'gzip --best' .
-
-#   increase or update version information
-new-version:
-        @V="$(VERSION)"; \
-        if [ ".$$V" != . ]; then \
-                OPT="-s$$V"; \
-        else \
-                OPT="-e"; \
-        fi; \
-        $(_VERSION)
-update-version:
-        @OPT="-s`$(SHTOOL) version -lc -dshort $(_VERSION_FILE)`" && $(_VERSION)
-
 #   create dependencies
 depend: all
         cp Makefile.in Makefile.in.bak \


ossp-pkg/l2/autogen.sh 1.4 -> 1.5



ossp-pkg/l2/devtool -> 1.1

*** /dev/null    Sat Apr 20 13:37:11 2024
--- -    Sat Apr 20 13:40:59 2024
***************
*** 0 ****
--- 1,47 ----
+ #!/bin/sh
+ ##
+ ##  devtool -- Development Tool
+ ##  Copyright (c) 2001 Ralf S. Engelschall <rse@engelschall.com> 
+ ##
+ 
+ if [ $# -eq 0 ]; then
+     echo "devtool:USAGE: devtool <command> [<arg> ...]" 1>&2
+     exit 1
+ fi
+ 
+ cmd="$1"
+ shift
+ 
+ devtoolfunc="./devtool.func"
+ 
+ if [ ! -f devtool.conf ]; then
+     echo "devtool:ERROR: no devtool.conf in current directory" 1>&2
+     exit 1
+ fi
+ 
+ cmdline=`grep "^%$cmd" devtool.conf`
+ if [ ".$cmdline" = . ]; then
+     echo "devtool:ERROR: command $cmd not found in devtool.conf" 1>&2
+     exit 1
+ fi
+ 
+ if [ ".$TMPDIR" != . ]; then
+     tmpdir="$TMPDIR"
+ elif [ ".$TEMPDIR" != . ]; then
+     tmpdir="$TEMPDIR"
+ else
+     tmpdir="/tmp"
+ fi
+ tmpfile="$tmpdir/rc.$$.tmp"
+ 
+ rm -f $tmpfile
+ touch $tmpfile
+ echo ". $devtoolfunc" >>$tmpfile
+ ( sed <devtool.conf -e "1,/^%common/d" -e '/^%.*/,$d'
+   sed <devtool.conf -e "1,/^%$cmd/d" -e '/^%.*/,$d' ) |\
+ sed -e 's;\([  ]\)@\([a-zA-Z_][a-zA-Z0-9_]*\);\1devtool_\2;' >>$tmpfile
+ 
+ sh $tmpfile "$@"
+ 
+ rm -f $tmpfile >/dev/null 2>&1 || true
+ 


ossp-pkg/l2/devtool.conf -> 1.1

*** /dev/null    Sat Apr 20 13:37:11 2024
--- -    Sat Apr 20 13:40:59 2024
***************
*** 0 ****
--- 1,31 ----
+ ##
+ ##  devtool.conf -- Development Tool Configuration
+ ##
+ 
+ %autogen
+     @autogen shtool   1.5.4 "1.5.*" all
+     @autogen libtool  1.4.2 "1.4*"
+     @autogen autoconf 2.52  "2.5.*"
+ 
+ %autoclean
+     @autoclean shtool
+     @autoclean libtool
+     @autoclean autoconf
+ 
+ %configure
+     ./configure \
+         --prefix=/tmp/l2 \
+         --disable-shared \
+         --enable-debug \
+         "$@"
+ 
+ %version
+     ./shtool version -l c -n "OSSP L2" -p "l2_" -e l2_version.c
+ 
+ %dist
+     make distclean >/dev/null 2>&1
+     ./shtool fixperm -v .
+     V=`./shtool version -l c -d short l2_version.c`
+     ./shtool tarball -o l2-${V}.tar.gz -d l2-${V} -u ossp -g ossp \
+                      -e 'CVS,\.cvsignore,\.[ao],^\.,devtool.conf' -c 'gzip --best' .
+ 


ossp-pkg/l2/devtool.func -> 1.1

*** /dev/null    Sat Apr 20 13:37:11 2024
--- -    Sat Apr 20 13:40:59 2024
***************
*** 0 ****
--- 1,72 ----
+ ##
+ ##  devtool.func -- Development Tool Functions
+ ##  Copyright (c) 2001 Ralf S. Engelschall <rse@engelschall.com> 
+ ##
+ 
+ devtool_require () {
+     t="$1"; o="$2"; p="$3"; e="$4"; a="$5"
+     v=`($t $o | head -1 | awk "{ print \\\$$p; }") 2>/dev/null`
+     if [ ".$v" = . ]; then
+         echo "devtool:ERROR: unable to determine version of $t" 1>&2
+         exit 1
+     fi
+     case "$v" in
+         $e )
+             ;;
+         $a )
+             echo "devtool:WARNING: $t version $v still accepted, although expected $e." 1>&2
+             ;;
+         * )
+             echo "devtool:ERROR: $t version $e expected, but found $v." 1>&2
+             exit 1
+             ;;
+     esac
+     echo "$v"
+ }
+ 
+ devtool_autogen () {
+     tool=$1
+     shift
+     case $tool in
+         autoconf )
+             autoconf_version=`devtool_require autoconf --version 4 "$1" "$2"`
+             echo "generating (GNU Autoconf $autoconf_version): configure config.h.in"
+             autoconf
+             autoheader 2>&1 | grep -v "is unchanged"
+             ;;
+         libtool )
+             libtoolize_version=`devtool_require libtoolize --version 4 "$1" "$2"`
+             echo "generating (GNU Libtool $libtoolize_version): ltmain.sh, libtool.m4, config.guess, config.sub"
+             libtoolize --force --copy >/dev/null 2>&1
+             cp `libtoolize --force --copy --dry-run | grep "add the contents of" |\
+                 sed -e 's;^[^\`]*\`;;' -e "s;'.*;;"` libtool.m4
+             ;;
+         shtool )
+             shtoolize_version=`devtool_require shtoolize -v 3 "$1" "$2"`
+             echo "generating (GNU Shtool $shtoolize_version): shtool"
+             shift
+             shift
+             shtoolize -q "$@"
+             ;;
+     esac
+ }
+ 
+ devtool_autoclean () {
+     tool=$1
+     shift
+     case $tool in
+         autoconf )
+             echo "removing: configure config.h.in"
+             rm -f configure config.h.in
+             ;;
+         libtool )
+             echo "removing: ltmain.sh libtool.m4 config.guess config.sub"
+             rm -f ltmain.sh libtool.m4 config.guess config.sub
+             ;;
+         shtool )
+             echo "removing: shtool"
+             rm -f shtool
+             ;;
+     esac
+ }
+ 


ossp-pkg/l2/l2_version.c 1.3 -> 1.4

--- l2_version.c 2001/09/13 14:22:02     1.3
+++ l2_version.c 2001/11/08 09:53:34     1.4
@@ -1,5 +1,5 @@
 /*
 **  l2_version.c -- Version Information for L2 (syntax: C/C++)
 **  [automatically generated and maintained by GNU shtool]
 */
 
@@ -8,7 +8,7 @@
 #ifndef _L2_VERSION_C_
 #define _L2_VERSION_C_
 
-#define L2_VERSION 0x001200
+#define L2_VERSION 0x002200
 
 typedef struct {
     const int   v_hex;
@@ -32,14 +32,14 @@
 #undef  _L2_VERSION_C_AS_HEADER_
 
 l2_version_t l2_version = {
-    0x001200,
-    "0.1.0",
-    "0.1.0 (13-Sep-2001)",
-    "This is L2, Version 0.1.0 (13-Sep-2001)",
-    "L2 0.1.0 (13-Sep-2001)",
-    "L2/0.1.0",
-    "@(#)L2 0.1.0 (13-Sep-2001)",
-    "$Id: L2 0.1.0 (13-Sep-2001) $"
+    0x002200,
+    "0.2.0",
+    "0.2.0 (08-Nov-2001)",
+    "This is OSSP L2, Version 0.2.0 (08-Nov-2001)",
+    "OSSP L2 0.2.0 (08-Nov-2001)",
+    "OSSP L2/0.2.0",
+    "@(#)OSSP L2 0.2.0 (08-Nov-2001)",
+    "$Id: OSSP L2 0.2.0 (08-Nov-2001) $"
 };
 
 #endif /* _L2_VERSION_C_AS_HEADER_ */
@@ -1,5 +1,5 @@
 /*
-**  l2_version.c -- Version Information for L2 (syntax: C/C++)
+**  l2_version.c -- Version Information for OSSP L2 (syntax: C/C++)
 **  [automatically generated and maintained by GNU shtool]
 */

CVSTrac 2.0.1